@@ -195,12 +195,12 @@ class PGBM(object):
         return mu, variance
     
     @staticmethod
-    @njit(fastmath=True, parallel=True)
+    @njit(fastmath=True)
     def _create_X_splits(X, bins, max_bin):
         # Pre-compute split decisions for Xtrain
         X_splits = np.zeros((X.shape[1], X.shape[0]), dtype=np.int32)
         
-        for i in prange(max_bin):
+        for i in range(max_bin):
             X_splits += (X > bins[:, i]).T
     
         return X_splits
@@ -380,28 +380,31 @@ class PGBM(object):
         if self.params['distribution'] == 'normal':
             loc = mu
             scale = np.sqrt(variance)
-            yhat = np.random.normal(loc, scale, (n_forecasts, loc.shape[0]))
+            yhat = np.random.normal(loc, scale, (n_forecasts, mu.shape[0]))
         elif self.params['distribution'] == 'laplace':
             loc = mu
-            scale = np.clip(np.sqrt(0.5 * variance), 1e-9)
-            yhat =  np.random.laplace(loc, scale, (n_forecasts, loc.shape[0]))
+            scale = np.sqrt(0.5 * variance)
+            scale = np.clip(scale, 1e-9, scale.max())
+            yhat =  np.random.laplace(loc, scale, (n_forecasts, mu.shape[0]))
         elif self.params['distribution'] == 'logistic':
             loc = mu
-            scale = np.clip(np.sqrt((3 * variance) / np.pi**2), 1e-9)
-            yhat =  np.random.logistic(loc, scale, (n_forecasts, loc.shape[0]))
+            scale = np.sqrt((3 * variance) / np.pi**2)
+            scale = np.clip(scale, 1e-9, scale.max())
+            yhat =  np.random.logistic(loc, scale, (n_forecasts, mu.shape[0]))
         elif self.params['distribution'] == 'gamma':
-            variance = np.clip(variance, 1e-9)
-            mu = np.clip(mu, 1e-9)
-            rate = (mu / variance)
-            shape = mu * rate
-            yhat =  np.random.gamma(shape, rate, (n_forecasts, loc.shape[0]))
+            variance = np.clip(variance, 1e-9, variance.max())
+            mu = np.clip(mu, 1e-9, mu.max())
+            shape = mu**2 / variance
+            scale = mu / shape
+            yhat =  np.random.gamma(shape, scale, (n_forecasts, mu.shape[0]))
         elif self.params['distribution'] == 'gumbel':
-            variance = np.clip(variance, 1e-9)
-            scale = np.clip(np.sqrt(6 * variance / np.pi**2), 1e-9)
+            variance = np.clip(variance, 1e-9, variance.max())
+            scale = np.sqrt(6 * variance / np.pi**2)
+            scale = np.clip(scale, 1e-9, scale.max())
             loc = mu - scale * np.euler_gamma
-            yhat =  np.random.gumbel(loc, scale, (n_forecasts, loc.shape[0]))
+            yhat =  np.random.gumbel(loc, scale, (n_forecasts, mu.shape[0]))
         elif self.params['distribution'] == 'poisson':
-            yhat = np.random.poisson(loc, scale, (n_forecasts, loc.shape[0]))
+            yhat = np.random.poisson(loc, scale, (n_forecasts, mu.shape[0]))
         else:
             print('Distribution not (yet) supported')
         
@@ -542,11 +545,10 @@ class PGBM(object):
         # Calculate base score
         yhat_base = self.predict(X)
         if y is not None:
-            y = self._convert_array(y)
             base_metric = self.metric(yhat_base, y, levels)
         # Loop over permuted features
         for feature in range(n_features):
-            X_permuted = np.zeros((n_permutations, n_samples, n_features), device=X.device, dtype=X.dtype)
+            X_permuted = np.zeros((n_permutations, n_samples, n_features), dtype=X.dtype)
             for permutation in range(n_permutations):
                 indices = np.random.choice(n_samples, n_samples)
                 X_current = X.copy()
@@ -561,7 +563,7 @@ class PGBM(object):
                     permuted_metric = self.metric(yhat[permutation], y, levels)
                     permutation_importance_metric[feature, permutation] = ((permuted_metric / base_metric) - 1) * 100
             else:
-                permutation_importance_metric[feature] = (yhat_base[None, :] - yhat).abs().sum(1) / yhat_base.sum() * 100                
+                permutation_importance_metric[feature] = np.abs(yhat_base[None, :] - yhat).sum(1) / yhat_base.sum() * 100                
         
         return permutation_importance_metric
     
